@@ -20,6 +20,7 @@ def main(argv=None):
 
     inputfile = ""
     opts = ""
+    git_repo = ""
 
     try:
         opts, args = getopt.getopt(
@@ -57,7 +58,7 @@ def main(argv=None):
         elif opt in ("-n", "--name"):
             settings.APP_NAME = arg
         elif opt in ("-g", "--git-repository-ssh"):
-            git_repo = arg
+            settings.GIT_REPO = arg
     settings.SRC_DIR = this_dir
 
     if inputfile == "":
